summaryrefslogtreecommitdiff
path: root/app/Report/ReportHtmlFootnote.php
diff options
context:
space:
mode:
authorGreg Roach <fisharebest@webtrees.net>2018-10-05 14:45:31 +0100
committerGreg Roach <fisharebest@webtrees.net>2018-10-05 14:45:31 +0100
commit589feda391b943b928aea0b4107591eb0e7bbf89 (patch)
tree9181107385266814c3681d6bf53abbbdd420a592 /app/Report/ReportHtmlFootnote.php
parent1121bd6832d8a9897a30155d22c635239a794d4d (diff)
downloadwebtrees-589feda391b943b928aea0b4107591eb0e7bbf89.tar.gz
webtrees-589feda391b943b928aea0b4107591eb0e7bbf89.tar.bz2
webtrees-589feda391b943b928aea0b4107591eb0e7bbf89.zip
Strict types in reports
Diffstat (limited to 'app/Report/ReportHtmlFootnote.php')
-rw-r--r--app/Report/ReportHtmlFootnote.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/app/Report/ReportHtmlFootnote.php b/app/Report/ReportHtmlFootnote.php
index f0159b25ec..00bb641ad7 100644
--- a/app/Report/ReportHtmlFootnote.php
+++ b/app/Report/ReportHtmlFootnote.php
@@ -71,11 +71,11 @@ class ReportHtmlFootnote extends ReportBaseFootnote
* Calculates the Footnotes height
*
* @param ReportHtml $html
* @param int $cellWidth The width of the cell to use it for text wraping
*
* @return int Footnote height in points
*/
- public function getFootnoteHeight($html, $cellWidth = 0): int
+ public function getFootnoteHeight($html, float $cellWidth = 0): float
{
if ($html->getCurrentStyle() != $this->styleName) {
$html->setCurrentStyle($this->styleName);
@@ -71,11 +71,11 @@ class ReportHtmlFootnote extends ReportBaseFootnote
*
* @param ReportHtml $html
- * @param int $cellWidth The width of the cell to use it for text wraping
+ * @param float $cellWidth The width of the cell to use it for text wraping
*
@@ -71,11 +71,11 @@ class ReportHtmlFootnote extends ReportBaseFootnote
*
- * @return int Footnote height in points
+ * @return float Footnote height in points
*/